@@ -17,9 +17,8 @@ import tempfile
 import zipfile
 
 from .path import onerror
-from .shim import which
 
-LOG = logging.getLogger('fuzzfetch')
+LOG = logging.getLogger("fuzzfetch")
 
 
 HDIUTIL_PATH = None
@@ -36,56 +35,54 @@ def _extract_file(zip_fp, info, path):
     os.chmod(out_path, perm)
 
 
-def extract_zip(zip_fn, path='.'):
+def extract_zip(zip_fn, path="."):
     """
     Download and extract a zip artifact
 
-    @type zip_fn:
-    @param zip_fn:
-
-    @type path:
-    @param path:
+    Arguments:
+        zip_fn
+        path
     """
     global P7Z_PATH  # pylint: disable=global-statement
     if P7Z_PATH is None:
-        P7Z_PATH = which('7z') or ''
+        P7Z_PATH = shutil.which("7z") or ""
     if P7Z_PATH:
-        subprocess.check_output([P7Z_PATH, 'x', '-bd', '-o' + path, zip_fn])
+        subprocess.check_output([P7Z_PATH, "x", "-bd", "-o" + path, zip_fn])
     else:
         with zipfile.ZipFile(zip_fn) as zip_fp:
             for info in zip_fp.infolist():
                 _extract_file(zip_fp, info, path)
 
 
-def extract_tar(tar_fn, mode='', path='.'):
+def extract_tar(tar_fn, mode="", path="."):
     """
     Extract builds with .tar.(*) extension
     When unpacking a build archive, only extract the firefox directory
 
-    @type tar_fn:
-    @param tar_fn:
-
-    @type mode:
-    @param mode:
-
-    @type path:
-    @param path:
+    Arguments:
+        tar_fn
+        mode
+        path
     """
     global P7Z_PATH  # pylint: disable=global-statement
     if P7Z_PATH is None:
-        P7Z_PATH = which('7z') or ''
+        P7Z_PATH = shutil.which("7z") or ""
     try:
-        if P7Z_PATH and mode in {'7z', 'bz2', 'gz', 'lzma', 'xz'}:
-            p7z_fd, p7z_fn = tempfile.mkstemp(prefix='fuzzfetch-', suffix='.tar')
+        if P7Z_PATH and mode in {"7z", "bz2", "gz", "lzma", "xz"}:
+            p7z_fd, p7z_fn = tempfile.mkstemp(prefix="fuzzfetch-", suffix=".tar")
             with open(os.devnull, "w") as devnull:
-                result = subprocess.call([P7Z_PATH, 'e', '-so', tar_fn], stdout=p7z_fd, stderr=devnull)
+                result = subprocess.call(
+                    [P7Z_PATH, "e", "-so", tar_fn], stdout=p7z_fd, stderr=devnull
+                )
             os.close(p7z_fd)
             if result == 0:
-                mode = ''
+                mode = ""
                 tar_fn = p7z_fn
             else:
-                LOG.warning('7z was found, but returned %d decompressing %r', result, tar_fn)
-        with tarfile.open(tar_fn, mode='r:%s' % mode) as tar:
+                LOG.warning(
+                    "7z was found, but returned %d decompressing %r", result, tar_fn
+                )
+        with tarfile.open(tar_fn, mode="r:%s" % mode) as tar:
             members = []
             for member in tar.getmembers():
                 if member.path.startswith("firefox/"):
@@ -100,27 +97,33 @@ def extract_tar(tar_fn, mode='', path='.'):
             os.unlink(p7z_fn)
 
 
-def extract_dmg(dmg_fn, path='.'):
+def extract_dmg(dmg_fn, path="."):
     """
     Extract builds with .dmg extension
 
     Will only work if `hdiutil` is available.
 
-    @type path:
-    @param path:
+    Arguments:
+        path
     """
     global HDIUTIL_PATH  # pylint: disable=global-statement
     if HDIUTIL_PATH is None:
-        HDIUTIL_PATH = which('hdiutil') or ''
-    assert HDIUTIL_PATH, 'Extracting .dmg requires hdiutil'
-    out_tmp = tempfile.mkdtemp(prefix='fuzzfetch-', suffix='.tmp')
+        HDIUTIL_PATH = shutil.which("hdiutil") or ""
+    assert HDIUTIL_PATH, "Extracting .dmg requires hdiutil"
+    out_tmp = tempfile.mkdtemp(prefix="fuzzfetch-", suffix=".tmp")
     try:
-        subprocess.check_call([HDIUTIL_PATH, 'attach', '-quiet', '-mountpoint', out_tmp, dmg_fn])
+        subprocess.check_call(
+            [HDIUTIL_PATH, "attach", "-quiet", "-mountpoint", out_tmp, dmg_fn]
+        )
         try:
-            apps = [mt for mt in os.listdir(out_tmp) if mt.endswith('app')]
+            apps = [mt for mt in os.listdir(out_tmp) if mt.endswith("app")]
             assert len(apps) == 1
-            shutil.copytree(os.path.join(out_tmp, apps[0]), os.path.join(path, apps[0]), symlinks=True)
+            shutil.copytree(
+                os.path.join(out_tmp, apps[0]),
+                os.path.join(path, apps[0]),
+                symlinks=True,
+            )
         finally:
-            subprocess.check_call([HDIUTIL_PATH, 'detach', '-quiet', out_tmp])
+            subprocess.check_call([HDIUTIL_PATH, "detach", "-quiet", out_tmp])
     finally:
         shutil.rmtree(out_tmp, onerror=onerror)
